.. include:: ../../../README.rst

Find a section
=================
.. toctree::
   :maxdepth: 2

   quickstart
   development
   configuration
   howtos
   run-a-study
   how-to-produce-csv
   how-to-use-fairness-metrics
   how-to-rerank
   integrations
   configuration_file
   configuration_checking
   python-side-evaluation
   supported-algorithms
   command-line

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
